@@ -120,7 +120,12 @@ class DcsConnection:
             self.__start__()
         else:
             logging.debug(str(id(self)) + " threads already running")
-        result = self.__dcsConnect__()
+        try:
+            result = self.__dcsConnect__()
+        except Exception as e:
+            logging.warning(str(id(self)) + " Failed to open socket " + str(self.__serial__ ) + "@" + str(self.__serverAddress__) + ":" + str(self.__serverPort__) + ". Server down or network error?")
+            self.__keepConnected__ = True
+            return False
         if not result:
             logging.warning(str(id(self)) + " Failed to connect " + str(self.__serial__ ) + "@" + str(self.__serverAddress__) + ":" + str(self.__serverPort__) + ". Check encryption key!")
         else:
@@ -415,7 +420,7 @@ class DcsConnection:
                 return True
             else:
                 logging.error(str(id(self)) + " connection failed. No socket available")
-                return False
+                raise Exception("socket error")
 
     def __checkSocket__(self):
         with self.__socketLock__:
@@ -444,7 +449,7 @@ class DcsConnection:
                 self.__socket__.connect((host, self.__serverPort__))
                 break
             except Exception:
-                logging.warning(str(id(self)) + " Cannot connect to " + str(host) + ":" + str(self.__serverPort__) + ".")
+                logging.warning(str(id(self)) + " Cannot open socket to " + str(host) + ":" + str(self.__serverPort__) + ".")
                 socketRetries = socketRetries + 1
                 time.sleep(SOCKETWAITTIME)
             if socketRetries > SOCKETRETRIES:
