@@ -84,6 +84,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             errorcode = None
 
         errorrate = self.getcommunicationerrorsrate()
+        modbusmodulestate = self.getmodbusmodulestate()
 
         data={
             "device": self.__devicetype__,
@@ -118,6 +119,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             "ww2target": self.getdataset("boost_temp_target"),
             "ww2offset": self.getdataset("ww2offset_calibration"),
             "modbuserrorrate":  errorrate,
+            "modbusmodulestate": modbusmodulestate,
             "errorcode_elwa": errorcode
         }       
         return data
@@ -151,7 +153,11 @@ class DeviceDcElwa(ModbusRtuDevice):
         pvprod = dcPower
 
         sLog={
-			"modbus_error_rate" : self.getcommunicationerrorsrate(),
+            "logdataage": self.getlogdataage(),
+            "healthstate": self.getHealthState(),
+            "errorcode": self.__errorcode__,
+            "modbus_if_state": self.getmodbusmodulestate(),
+			"modbus_error_rate": self.getcommunicationerrorsrate(),
 			"day_counter" : self.getintlogvalue("day_counter"),
 			"op_mode": self.getintlogvalue("operation_mode"),
 			"dc_breaker": self.getintlogvalue("dc_breaker_state"),
