@@ -15,6 +15,14 @@ class ModbusConnection:     #Singleton
     __modbusConnection__ = None
     __modbusClient__ = None
     __mutex__ = threading.Lock()
+    __modbusModuleState = None
+    __modbus_stopbits = 1
+    __modbusbytesize = 8
+    __modbusparity = 'N'
+    __modbusbaudrate = 9600
+    __modbustimeout = 0.2
+    __modbusretryonempty = True
+    __modbusretryoninvalid = True
 
     @staticmethod
     def instance():
@@ -33,7 +41,7 @@ class ModbusConnection:     #Singleton
 
         self.__connectionErrorCounter__ = dict()
         self.__connectionCounter__ = dict()
-        self.__modbusClient__ = ModbusClient(method = "rtu", port="/dev/ttyUSB0", stopbits = 1, bytesize = 8, parity = 'N', baudrate= 9600, timeout=0.2, retry_on_empty=True, retry_on_invalid=True)
+        self.__modbusClient__ = ModbusClient(method = "rtu", port="/dev/ttyUSB0", stopbits = self.__modbus_stopbits, bytesize = self.__modbusbytesize, parity = self.__modbusparity, baudrate= self.__modbusbaudrate, timeout=self.__modbustimeout, retry_on_empty=self.__modbusretryonempty, retry_on_invalid=self.__modbusretryoninvalid)
 
     def __increaseModbusErrorCounter__(self, nodeId):
         try:
@@ -45,6 +53,19 @@ class ModbusConnection:     #Singleton
         counter = self.__connectionErrorCounter__[nodeId]
         return counter
 
+    def setConfiguration(self, stopbits, bytesize, parity, baudrate, timeout, retry_on_empty, retry_on_invalid):
+        self.__modbus_stopbits = stopbits
+        self.__modbusbytesize = bytesize
+        self.__modbusparity = parity
+        self.__modbusbaudrate = baudrate
+        self.__modbustimeout = timeout
+        self.__modbusretryonempty = retry_on_empty
+        self.__modbusretryoninvalid = retry_on_invalid
+
+        with self.__mutex__:
+            self.__modbusClient__.close()
+            self.__modbusClient__ = ModbusClient(method = "rtu", port="/dev/ttyUSB0", stopbits = self.__modbus_stopbits, bytesize = self.__modbusbytesize, parity = self.__modbusparity, baudrate= self.__modbusbaudrate, timeout=self.__modbustimeout, retry_on_empty=self.__modbusretryonempty, retry_on_invalid=self.__modbusretryoninvalid)
+
     def getModbusErrorCounter(self, nodeId):
         try:
             return self.__connectionErrorCounter__[nodeId]
@@ -64,6 +85,9 @@ class ModbusConnection:     #Singleton
             logging.warning("[ModbusConnection] Node " + str(node) + ": Cannot calculate error rate.")
             return None
 
+    def getModbusModuleState(self):
+        return self.__modbusModuleState
+
     def resetCounters(self, nodeId):
         with self.__mutex__:
             try:
@@ -79,8 +103,10 @@ class ModbusConnection:     #Singleton
                 self.__modbusConnection__ = self.__modbusClient__.connect()
                 if(self.__modbusConnection__ != True):
                     logging.error("[ModbusConnection] Cannot connect modbus. Check modbus module.")
+                    raise Exception("Module Error")
             except Exception as e:
                 logging.error("[ModbusConnection] Unknown modbus connection error: " + str(e))
+                raise(e)
         return self.__modbusConnection__
 
     def checkmodbusconnection(self):
@@ -95,7 +121,12 @@ class ModbusConnection:     #Singleton
             except:
                 self.__connectionCounter__[node] = 1
             if self.__modbusClient__ != None:
-                if(self.__connectSocket__()):
+                try:
+                    socket = self.__connectSocket__()
+                except Exception as e:
+                    logging.warning("[ModbusConnection] Modbus socket error: " + str(e))
+                    socket = None
+                if(socket):
                     try:
                         result = self.__modbusClient__.write_register(registerId, value, unit = node)
                         if result.isError():
@@ -120,7 +151,13 @@ class ModbusConnection:     #Singleton
                 self.__connectionCounter__[node] = 1
             
             if self.__modbusClient__ != None:
-                if(self.__connectSocket__()):
+                try:
+                    socket = self.__connectSocket__()
+                except Exception as e:
+                    logging.warning("[ModbusConnection] Modbus socket error: " + str(e))
+                    socket = None
+                if(socket):
+                    self.__modbusModuleState = "CONNECTED"
                     registers = dict()
                     try:
                         if type == "input":
@@ -141,7 +178,8 @@ class ModbusConnection:     #Singleton
                         self.__increaseModbusErrorCounter__(node)
                         time.sleep(BUSRECOVERYTIME)
                 else:
-                    logging.debug("[ModbusConnection] Cannot read from node " + str(node) + ". Modbus-Socket not connected.")
+                    logging.debug("[ModbusConnection] Cannot read from node " + str(node) + ". Modbus-Socket not connected. Module Error?")
+                    self.__modbusModuleState = "ERROR"
             return None
 
     def readinputregisters(self, node, startAddress = 1000, registersToRead = 1):
@@ -156,13 +194,25 @@ if __name__ == "__main__":
     unitToTest = 1
 
     # trying to use modbus module
-    socket = ModbusConnection.instance().__connectSocket__()
+    try:
+        socket = ModbusConnection.instance().__connectSocket__()
+    except:
+        socket = None
     if(socket == True):
         print(color('SUCCESS: Using modbus module.', fore='green', style='bright'))
     else:
         print(color('ERROR: Using modbus module.', fore='red', style='bright'))
         input("PRESS ENTER TO CONTINUE TESTING")
 
+    # testing module state
+    internalTempRegisterNumber = 1021
+    register = ModbusConnection.instance().readregisters(unitToTest, internalTempRegisterNumber, 1)
+    state =  ModbusConnection.instance().getModbusModuleState()
+    if(state == "CONNECTED"):
+        print(color('SUCCESS: Modbus module state check.', fore='green', style='bright'))
+    else:
+        print(color('ERROR: Modbus module state check.', fore='red', style='bright'))
+
     # trying to read temperature from modbus module internal sensor
     internalTempRegisterNumber = 1021
     register = ModbusConnection.instance().readregisters(unitToTest, internalTempRegisterNumber, 1)
@@ -243,6 +293,18 @@ if __name__ == "__main__":
     else:
         print(color('ERROR: Valid multiple register read multiple times.', fore='red', style='bright'))
 
+    # trying to change configuration
+    internalTempRegisterNumber = 1021
+    ModbusConnection.instance().setConfiguration(1, 8, 'N', 19200, 0.2, True, True)     #change to invalid baudrate
+    registerInvalid = ModbusConnection.instance().readregisters(unitToTest, internalTempRegisterNumber, 1)
+    ModbusConnection.instance().setConfiguration(1, 8, 'N', 9600, 0.2, True, True)  #chnage to valid baudrate
+    registerValid = ModbusConnection.instance().readregisters(unitToTest, internalTempRegisterNumber, 1)
+
+    if(registerValid != None and registerValid != {} and registerInvalid == None):
+        print(color('SUCCESS: Configuration change test.', fore='green', style='bright'))
+    else:
+        print(color('ERROR: Configuration change test.', fore='red', style='bright'))
+
     # writing to vaild node
     ModbusConnection.instance().resetCounters(unitToTest)
     register = 1023
