@@ -6,6 +6,7 @@ from datetime import datetime
 from colr import color
 import sys
 import os
+import json
 
 PACKAGE_PARENT = '..'
 SCRIPT_DIR = os.path.dirname(os.path.realpath(os.path.join(os.getcwd(), os.path.expanduser(__file__))))
@@ -61,6 +62,9 @@ class ModbusRtuDevice(ModbusDevice):
     def getcommunicationerrorsrate(self):
         return ModbusConnection.instance().getModbusErrorRate(self.__nodeId__)
 
+    def getmodbusmodulestate(self):
+        return ModbusConnection.instance().getModbusModuleState()
+
     def getdata(self):
         t = datetime.now()
         data = {
@@ -73,6 +77,14 @@ class ModbusRtuDevice(ModbusDevice):
                 }            
         return data
 
+    def getlogdata(self, time=None):
+        logdata = super().getlogdata(time=time)
+        logdata["s_json"] = json.dumps({
+            "modbus_if_state": self.getmodbusmodulestate(),
+            "modbus_error_rate": self.getcommunicationerrorsrate(),
+        })
+        return logdata
+
 # Entry Point     
 if __name__ == "__main__":
 
